@@ -26,7 +26,7 @@ Implementation Notes
 # imports
 import displayio
 
-__version__ = "1.2.2"
+__version__ = "1.2.4"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_DisplayIO_SH1106.git"
 
 
@@ -103,7 +103,7 @@ class SH1106(displayio.Display):
             4) The MP can access (update) the built-in display RAM
         """
         if self._is_awake:
-            self.bus.send(int(0xAE), "")  # 0xAE = display off, sleep mode
+            self.bus.send(0xAE, b"")  # 0xAE = display off, sleep mode
             self._is_awake = False
 
     def wake(self):
@@ -111,5 +111,5 @@ class SH1106(displayio.Display):
         Wake display from sleep mode
         """
         if not self._is_awake:
-            self.bus.send(int(0xAF), "")  # 0xAF = display on
+            self.bus.send(0xAF, b"")  # 0xAF = display on
             self._is_awake = True
